pub fn runtime_context() -> &'static RuntimeContextExpand description
Get the global runtime context (detected lazily on first call).
All modules should use this instead of reading env vars directly. The context is immutable after first detection.
pub fn runtime_context() -> &'static RuntimeContextGet the global runtime context (detected lazily on first call).
All modules should use this instead of reading env vars directly. The context is immutable after first detection.