check_profile

Function check_profile 

pub fn check_profile(expr: &str) -> Vec<String>
Available on crate feature expression only.
Scan an expression for restricted function calls using default config.

Returns a list of error strings (empty if all function calls are within the DFE profile). Equivalent to check_profile_with_config with ProfileConfig::default() (all restrictions active).