Json

Struct Json 

pub struct Json<T>(pub T);
Available on crate feature http-server only.
JSON Extractor / Response.

When used as an extractor, it can deserialize request bodies into some type that implements [serde::de::DeserializeOwned]. The request will be rejected (and a JsonRejection will be returned) if:

  • The request doesn’t have a Content-Type: application/json (or similar) header.
  • The body doesn’t contain syntactically valid JSON.
  • The body contains syntactically valid JSON, but it couldn’t be deserialized into the target type.
  • Buffering the request body fails.

⚠️ Since parsing JSON requires consuming the request body, the Json extractor must be last if there are multiple extractors in a handler. See “the order of extractors”

See JsonRejection for more details.

Extractor example

use axum::{
    extract,
    routing::post,
    Router,
};
use serde::Deserialize;

#[derive(Deserialize)]
struct CreateUser {
    email: String,
    password: String,
}

async fn create_user(extract::Json(payload): extract::Json<CreateUser>) {
    // payload is a `CreateUser`
}

let app = Router::new().route("/users", post(create_user));

When used as a response, it can serialize any type that implements [serde::Serialize] to JSON, and will automatically set Content-Type: application/json header.

If the Serialize implementation decides to fail or if a map with non-string keys is used, a 500 response will be issued whose body is the error message in UTF-8.

Response example

use axum::{
    extract::Path,
    routing::get,
    Router,
    Json,
};
use serde::Serialize;
use uuid::Uuid;

#[derive(Serialize)]
struct User {
    id: Uuid,
    username: String,
}

async fn get_user(Path(user_id) : Path<Uuid>) -> Json<User> {
    let user = find_user(user_id).await;
    Json(user)
}

async fn find_user(user_id: Uuid) -> User {
    // ...
}

let app = Router::new().route("/users/{id}", get(get_user));

Tuple Fields

0: T

Implementations

Source

impl<T> Json<T>

pub fn from_bytes(bytes: &[u8]) -> Result<Json<T>, JsonRejection>

Construct a Json<T> from a byte slice. Most users should prefer to use the FromRequest impl but special cases may require first extracting a Request into Bytes then optionally constructing a Json<T>.