pub fn setup(opts: LoggerOptions) -> Result<(), LoggerError>Available on crate feature
logger only.Expand description
Initialise the global logger with custom options.
Errors
Returns an error if the logger is already initialised.
pub fn setup(opts: LoggerOptions) -> Result<(), LoggerError>logger only.Initialise the global logger with custom options.
Returns an error if the logger is already initialised.