pub struct SecretValue {
pub data: Vec<u8>,
pub fetched_at: SystemTime,
pub metadata: SecretMetadata,
}secrets only.Expand description
Value retrieved from a secrets provider.
Fields
data: Vec<u8>The secret data (may be binary or text).
fetched_at: SystemTimeWhen this secret was fetched.
metadata: SecretMetadataMetadata from the provider.
Implementations
Sourceimpl SecretValue
impl SecretValue
Sourcepub fn with_metadata(data: Vec<u8>, metadata: SecretMetadata) -> Self
pub fn with_metadata(data: Vec<u8>, metadata: SecretMetadata) -> Self
Create a new secret value with metadata.
Sourcepub fn as_str(&self) -> SecretsResult<&str>
pub fn as_str(&self) -> SecretsResult<&str>
Sourcepub fn is_expired(&self, ttl_secs: u64) -> bool
pub fn is_expired(&self, ttl_secs: u64) -> bool
Check if the secret has expired based on TTL.
Sourcepub fn is_within_grace(&self, ttl_secs: u64, grace_secs: u64) -> bool
pub fn is_within_grace(&self, ttl_secs: u64, grace_secs: u64) -> bool
Check if the secret is within the stale grace period.