pub fn trigger()Available on crate feature
shutdown only.Expand description
Trigger shutdown programmatically.
Cancels the global token. All modules listening on it will begin their drain/cleanup sequence.
pub fn trigger()shutdown only.Trigger shutdown programmatically.
Cancels the global token. All modules listening on it will begin their drain/cleanup sequence.