pub enum OrderingMode {
Interleaved,
StrictFifo,
}tiered-sink only.Expand description
Ordering mode for message delivery during drain.
Variants
Interleaved
New messages go hot path, spool drains in background (default). Maximizes throughput with slight ordering relaxation. New messages may arrive before older spooled messages.
StrictFifo
Drain spool completely before new messages use hot path. Guarantees strict FIFO ordering but blocks new traffic during drain.