pub enum AnySender {
Grpc(GrpcTransport),
Memory(MemoryTransport),
Pipe(PipeTransport),
File(FileTransport),
Http(HttpTransport),
Redis(RedisTransport),
}transport only.Expand description
Type-erased transport sender.
Wraps any concrete transport sender behind an enum for runtime dispatch. Created by the transport factory from config.
Uses enum dispatch (not trait objects) because TransportSender
has impl Future return types which prevent dyn dispatch.
Variants
Grpc(GrpcTransport)
transport-grpc only.Memory(MemoryTransport)
transport-memory only.Pipe(PipeTransport)
transport-pipe only.File(FileTransport)
transport-file only.Http(HttpTransport)
transport-http only.Redis(RedisTransport)
transport-redis only.Implementations
Sourceimpl AnySender
impl AnySender
Sourcepub async fn from_config(key: &str) -> TransportResult<Self>
pub async fn from_config(key: &str) -> TransportResult<Self>
Sourcepub async fn from_transport_config(
config: &TransportConfig,
) -> TransportResult<Self>
pub async fn from_transport_config( config: &TransportConfig, ) -> TransportResult<Self>
Create a sender from an explicit TransportConfig.