CommitToken

Trait CommitToken 

pub trait CommitToken:
    Clone
    + Send
    + Sync
    + Debug
    + Display
    + 'static {
    // Provided method
    fn as_str(&self) -> String { ... }
}
Available on crate feature transport only.
Transport-specific token for commit/acknowledgment.

Each transport implementation provides its own token type that captures the information needed to acknowledge message processing.

Provided Methods

fn as_str(&self) -> String

Get a string representation for logging/debugging.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors