Module config

Module config 

Available on crate feature worker-batch and (crate features worker-batch or worker-pool or worker) only.

Structs

BatchProcessingConfig
Configuration for the batch processing engine.

Enums

ParseErrorAction
Action to take when a message fails to parse.
PreRouteFilterConfig
Pre-route filter applied to each message before routing decisions.