pub fn trigger()Expand description
Trigger shutdown programmatically.
Cancels the global token. All modules listening on it will begin their drain/cleanup sequence.
pub fn trigger()Trigger shutdown programmatically.
Cancels the global token. All modules listening on it will begin their drain/cleanup sequence.