Available on crate feature
worker-batch and (crate features worker-batch or worker-pool or worker) only.Structs
- Batch
Processing Config - Configuration for the batch processing engine.
Enums
- Parse
Error Action - Action to take when a message fails to parse.
- PreRoute
Filter Config - Pre-route filter applied to each message before routing decisions.