Module config

Module config 

Available on (crate features worker-pool or worker-batch or worker) and crate feature worker-batch only.

Structs

BatchProcessingConfig
Configuration for the batch processing engine.

Enums

ParseErrorAction
Action to take when a message fails to parse.
PreRouteFilterConfig
Pre-route filter applied to each message before routing decisions.