Available on (crate features
worker-pool or worker-batch or worker) and crate feature worker-batch only.Structs
- Batch
Processing Config - Configuration for the batch processing engine.
Enums
- Parse
Error Action - Action to take when a message fails to parse.
- PreRoute
Filter Config - Pre-route filter applied to each message before routing decisions.